@@ -5,7 +5,7 @@ describe 'ceilometer::agent::polling' do
   let :pre_condition do
     "include nova\n" +
     "include nova::compute\n" +
-    "class { 'ceilometer': metering_secret => 's3cr3t' }"
+    "class { 'ceilometer': telemetry_secret => 's3cr3t' }"
   end
 
   let :params do
@@ -48,7 +48,7 @@ describe 'ceilometer::agent::polling' do
       )
     end
 
-    it 'configures central agent' do
+    it 'configures polling namespaces' do
       is_expected.to contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('central,compute,ipmi')
     end
 
@@ -77,6 +77,18 @@ describe 'ceilometer::agent::polling' do
       end
     end
 
+    context 'with central and ipmi polling namespaces disabled' do
+      before do
+        params.merge!({
+          :central_namespace => false,
+          :ipmi_namespace    => false })
+      end
+
+      it 'configures compute polling namespace' do
+        is_expected.to contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('compute')
+      end
+    end
+
     context 'with disabled service managing' do
       before do
         params.merge!({
