@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'ceilometer::collector' do
 
   let :pre_condition do
-    "class { 'ceilometer': metering_secret => 's3cr3t' }"
+    "class { 'ceilometer': telemetry_secret => 's3cr3t' }"
   end
 
   shared_examples_for 'ceilometer-collector' do
@@ -68,7 +68,8 @@ describe 'ceilometer::collector' do
           :name       => platform_params[:collector_service_name],
           :enable     => true,
           :hasstatus  => true,
-          :hasrestart => true
+          :hasrestart => true,
+          :tag        => 'ceilometer-service'
         )
       end
 
@@ -87,7 +88,8 @@ describe 'ceilometer::collector' do
           :name       => platform_params[:collector_service_name],
           :enable     => false,
           :hasstatus  => true,
-          :hasrestart => true
+          :hasrestart => true,
+          :tag        => 'ceilometer-service'
         )
       end
     end
@@ -104,7 +106,8 @@ describe 'ceilometer::collector' do
           :name       => platform_params[:collector_service_name],
           :enable     => false,
           :hasstatus  => true,
-          :hasrestart => true
+          :hasrestart => true,
+          :tag        => 'ceilometer-service'
         )
       end
     end
