@@ -11,7 +11,7 @@ describe 'ceilometer::wsgi::apache' do
   end
 
   let :pre_condition do
-    "class { 'ceilometer': metering_secret => 's3cr3t' }"
+    "class { 'ceilometer': telemetry_secret => 's3cr3t' }"
   end
 
   shared_examples_for 'apache serving ceilometer with mod_wsgi' do
@@ -53,7 +53,7 @@ describe 'ceilometer::wsgi::apache' do
         'wsgi_script_aliases'         => { '/' => "#{platform_parameters[:wsgi_script_path]}/app" },
         'require'                     => 'File[ceilometer_wsgi]'
       )}
-      it { is_expected.to contain_file("#{platform_parameters[:httpd_ports_file]}") }
+      it { is_expected.to contain_concat("#{platform_parameters[:httpd_ports_file]}") }
     end
 
     describe 'when overriding parameters using different ports' do
@@ -81,7 +81,7 @@ describe 'ceilometer::wsgi::apache' do
         'require'                     => 'File[ceilometer_wsgi]'
       )}
 
-      it { is_expected.to contain_file("#{platform_parameters[:httpd_ports_file]}") }
+      it { is_expected.to contain_concat("#{platform_parameters[:httpd_ports_file]}") }
     end
   end
 
